Struct Take

pub struct Take<T> { /* private fields */ }
The take adapter.

See: Buf::take.

Implementations

Source

impl<T> Take<T>

pub fn left(&self) -> usize

Get the number of bytes logically left in the buffer.

This method is not the same as Buf::remaining(). It returns the maximum number of bytes the underlying buffer is allowed to have left. The returned value might be greater than the actual amount of bytes the underlying buffer has left.

pub fn set_left(&mut self, left: usize)

Set the maximum amount of bytes the underlying buffer is allowed to have.

pub fn get(&self) -> &T

Get a reference to the underlying buffer.

pub fn get_mut(&mut self) -> &mut T

Get a mutable reference to the underlying buffer.

pub fn into_inner(self) -> T

Destruct the adapter and get back the underlying buffer.