Trait WriteError

pub trait WriteError: IoError {
    // Required method
    fn write_zero() -> Self;
}
A trait that describes an error returned by Write and AsyncWrite.

Required Methods

fn write_zero() -> Self

Create a new error that indicates zero written bytes when writing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl WriteError for ErrorKind

Available on crate feature embedded-io only.
Source

fn write_zero() -> Self

Source

impl WriteError for Error

Available on crate feature std only.
Source

fn write_zero() -> Self

Source

impl WriteError for Error

Available on crate feature core2 only.
Source

fn write_zero() -> Self

Implementors