pub struct Take<T> { /* private fields */ }Expand description
The take adapter.
See: Buf::take.
Implementations
Sourceimpl<T> Take<T>
impl<T> Take<T>
Sourcepub fn left(&self) -> usize
pub fn left(&self) -> usize
Get the number of bytes logically left in the buffer.
This method is not the same as Buf::remaining(). It returns the maximum number
of bytes the underlying buffer is allowed to have left. The returned value might be
greater than the actual amount of bytes the underlying buffer has left.
Sourcepub fn set_left(&mut self, left: usize)
pub fn set_left(&mut self, left: usize)
Set the maximum amount of bytes the underlying buffer is allowed to have.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Destruct the adapter and get back the underlying buffer.