pub trait WriteError: IoError {
// Required method
fn write_zero() -> Self;
}Expand description
A trait that describes an error returned by Write and AsyncWrite.
Required Methods
Sourcefn write_zero() -> Self
fn write_zero() -> Self
Create a new error that indicates zero written bytes when writing.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl WriteError for ErrorKind
Available on crate feature embedded-io only.
impl WriteError for ErrorKind
Available on crate feature
embedded-io only.fn write_zero() -> Self
Sourceimpl WriteError for Error
Available on crate feature std only.
impl WriteError for Error
Available on crate feature
std only.fn write_zero() -> Self
Sourceimpl WriteError for Error
Available on crate feature core2 only.
impl WriteError for Error
Available on crate feature
core2 only.